@@ -730,8 +730,8 @@ kismet_ui.AddDeviceDetail("base", "Device Info", -1000, {
                     },
                     draw: function(opts) {
                         var loc =
-                            kismet.ObjectByString(opts['data'], "kismet.device.base.signal/kismet.common.signal.peak_loc/kismet.common.location.lat") + ", " +
-                            kismet.ObjectByString(opts['data'], "kismet.device.base.signal/kismet.common.signal.peak_loc/kismet.common.location.lon");
+                            kismet.ObjectByString(opts['data'], "kismet.device.base.signal/kismet.common.signal.peak_loc/kismet.common.location.geopoint[1]") + ", " +
+                            kismet.ObjectByString(opts['data'], "kismet.device.base.signal/kismet.common.signal.peak_loc/kismet.common.location.geopoint[0]");
 
                         return loc;
                     },
@@ -878,20 +878,32 @@ kismet_ui.AddDeviceDetail("base", "Device Info", -1000, {
                 // Fields in subgroup
                 fields: [
                 {
-                    field: "kismet.device.base.location/kismet.common.location.avg_loc/kismet.common.location.lat",
-                    title: "Latitude"
-                },
-                {
-                    field: "kismet.device.base.location/kismet.common.location.avg_loc/kismet.common.location.lon",
-                    title: "Longitude"
+                    field: "kismet.device.base.location/kismet.common.location.avg_loc/kismet.common.location.geopoint",
+                    title: "Location",
+                    draw: function(opts) {
+                        try {
+                            if (opts['value'][1] == 0 || opts['value'][0] == 0)
+                                return "<i>Unknown</i>";
+
+                            return opts['value'][1] + ", " + opts['value'][0]
+                        } catch (error) {
+                            return "<i>Unknown</i>";
+                        }
+                    }
                 },
                 {
                     field: "kismet.device.base.location/kismet.common.location.avg_loc/kismet.common.location.alt",
-                    title: "Altitude (meters)",
+                    title: "Altitude",
                     filter: function(opts) {
                         return (kismet.ObjectByString(opts['data'], "kismet.device.base.location/kismet.common.location.avg_loc/kismet.common.location.fix") >= 3);
-                    }
-
+                    },
+                    draw: function(opts) {
+                        try {
+                            return kismet_ui.renderHeightDistance(opts['value']);
+                        } catch (error) {
+                            return "<i>Unknown</i>";
+                        }
+                    },
                 }
                 ],
             }
@@ -1919,7 +1931,7 @@ exports.login_pending = false;
 
 exports.ProvisionedPasswordCheck = function(cb) {
     $.ajax({
-        url: "session/check_setup_ok",
+        url: local_uri_prefix + "session/check_setup_ok",
 
         error: function(jqXHR, textStatus, errorThrown) {
             cb(jqXHR.status);
@@ -1936,7 +1948,7 @@ exports.LoginCheck = function(cb, user, pw) {
     pw = pw || kismet.getStorage('kismet.base.login.password', '');
 
     $.ajax({
-        url: "session/check_login",
+        url: local_uri_prefix + "session/check_login",
 
         beforeSend: function (xhr) {
             xhr.setRequestHeader ("Authorization", "Basic " + btoa(user + ":" + pw));
@@ -2273,7 +2285,7 @@ exports.FirstLoginCheck = function(first_login_done_cb) {
 
             $.ajax({
                 type: "POST",
-                url: "session/set_password",
+                url: local_uri_prefix + "session/set_password",
                 data: postdata,
                 error: function(jqXHR, textStatus, errorThrown) {
                     alert("Could not set login, check your kismet server logs.")
